@@ -463,10 +463,10 @@ DeleteFileWithRetries(const char *const pn, const int logIfNoEnt)
 	}
 #endif
 	Log(0, "Hmmm, could not delete %s, will try again: %s\n", pn, strerror(errno));
-	sleep((rand() % 3) + 1);
+	sleep(((unsigned int) rand() % 3) + 1);
 	if (unlink(pn) == 0) { return 0; }
 	Log(0, "Hmmm, still could not delete %s, will one more time: %s\n", pn, strerror(errno));
-	sleep((rand() % 11) + 4);
+	sleep(((unsigned int) rand() % 11) + 4);
 	if (unlink(pn) == 0) { return 0; }
 	return (-1);
 }	/* DeleteFileWithRetries */
@@ -861,7 +861,11 @@ PostInit(void)
 			exit(1);
 		}
 		/* FYI only, not important, but write the most recent process' PID to the file. */
+#ifdef HAVE_SNPRINTF
+		snprintf(pidbuf, sizeof(pidbuf) - 1, "%u\n", (unsigned int) getpid());
+#else
 		sprintf(pidbuf, "%u\n", (unsigned int) getpid());
+#endif
 		if (write(gLockFd, pidbuf, strlen(pidbuf)) < 0) {
 			perror(gLockFile);
 			exit(1);
@@ -967,7 +971,12 @@ LoadCurrentSpoolFileContents(int logErrors)
 	memset(cp + gItemContentsSize, 0, gItemContentsAllocSize - gItemContentsSize);
 
 	/* Rewind it since we have to re-read it for parsing. */
-	if (fseek(fp, 0L, SEEK_SET) != 0L) {
+#ifdef HAVE_FSEEKO
+	if (fseeko(fp, (off_t) 0, SEEK_SET) != 0L)
+#else
+	if (fseek(fp, 0L, SEEK_SET) != 0L)
+#endif
+	{
 		LogPerror("rewind %s", gMyItemPath);
 		fclose(fp);
 		return (-1);
@@ -1324,11 +1333,10 @@ LogEndItemResult(int uiShow, int errorOccurred, const char *const fmt, ...)
 
 	time(&gLogTime);
 	memset(tstr, 0, sizeof(tstr));
-	memset(buf, 0, sizeof(buf));
-	(void) strcpy(buf, "\nresult=");
+	(void) STRNCPY(buf, "\nresult=");
 
 	va_start(ap, fmt);
-#ifdef HAVE_VSNPRINTF
+#ifdef HAVE_SNPRINTF
 	(void) vsnprintf(buf + 8, sizeof(buf) - 8, fmt, ap);
 #else
 	(void) vsprintf(buf + 8, fmt, ap);
@@ -1447,6 +1455,7 @@ PrLogStatBar(const FTPCIPtr cip, int mode)
 			break;
 
 		case kPrEndMsg:
+		default:
 			if (gProgLog == NULL)
 				return;
 
@@ -1885,6 +1894,8 @@ DoItem(void)
 			 */
 			result = 0;
 			break;
+		default:
+			break;
 	}
 
 	/* Return (result < 0) if the item should be re-spooled,
@@ -1948,6 +1959,8 @@ DecodeName(const char *const src, int *yyyymmdd, int *hhmmss, int *jobType)
 				}
 				valid = 0;
 				break;
+			default:
+				break;
 		}
 	}
 	if (valid < 0) {
@@ -2366,7 +2379,11 @@ ListQueue(int reportMode, int activeOnly)
 		}
 
 		memset(dstr, 0, sizeof(dstr));
+#ifdef HAVE_SNPRINTF
+		(void) snprintf(dstr, sizeof(dstr) - 1, "%08d%06d", iyyyymmdd, ihhmmss);
+#else
 		(void) sprintf(dstr, "%08d%06d", iyyyymmdd, ihhmmss);
+#endif
 		(void) memcpy(yyyy, dstr, 4); yyyy[4] = '\0';
 		(void) memcpy(mm, dstr + 4, 2); mm[2] = '\0';
 		(void) memcpy(dd, dstr + 6, 2); dd[2] = '\0';
@@ -2573,7 +2590,7 @@ static void OnDraw(HWND hwnd, HDC hdc)
 		//
 		ZeroMemory(&lf, (DWORD) sizeof(lf));
 		lf.lfHeight = -MulDiv(8, GetDeviceCaps(hdc, LOGPIXELSY), 72);
-		strcpy(lf.lfFaceName, "MS Sans Serif");
+		STRNCPY(lf.lfFaceName, "MS Sans Serif");
 		statusTextFont = CreateFontIndirect(&lf);
 		if (statusTextFont != NULL)
 			SendMessage(gStaticCtrl, WM_SETFONT, (WPARAM) statusTextFont, (LPARAM) 1);
